package com.muyu.vehicle.core;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.muyu.domain.Vehicle;
import com.muyu.service.VehicleService;
import com.muyu.vehicle.VehicleData;
import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PostConstruct;
import java.util.List;

/**
 * @author DongZeLiang
 * @version 1.0
 * @description 配置
 * @date 2023/11/9
 */
@Log4j2
@Configuration
@AllArgsConstructor
public class VehicleConfiguration implements ApplicationRunner {

    private final VehicleService vehicleService;

    /**
     * 初始化加载汽车数据到内存当中
     */
    public void vehicleInit(){
        long startTime = System.currentTimeMillis();
        int page = 0, pageSize = 1000;
        log.info("初始开始，批量从数据库当中加载数据到内存当中,每次[{}]条", pageSize);
        while (true){
            Page<Vehicle> vehiclePage = vehicleService.page(new Page<Vehicle>(page++, pageSize));
            List<Vehicle> records = vehiclePage.getRecords();
            records.forEach(LocalContainer::setVehicle);
            log.info("第[{}]页，[{}]条", page, records.size());
            if (records.size() < pageSize){
                break;
            }
        }
        log.info("数据加载完成，耗时：{}MS", System.currentTimeMillis() - startTime);
    }

    @Override
    public void run (ApplicationArguments args) throws Exception {
        this.vehicleInit();
    }
}
